Entering a Story — Django Stories v0.5 documentation

Django Stories v0.5 documentation

# Entering a Story

- Table of Contents
- index
  modules
  next
  previous

# Entering a Story

## Field Description

Headline
  Required. The headline of the story, up to 100 characters.
Subhead
  A sub-headline, or additional headline, to add more information. Limited to 200 characters.
Teaser Text
  Required. A brief description that could be used to “tease” the reader into reading the story by clicking on the link.
Body
  Required. The content of the story. If the GUI is installed, you can use it to format the copy.

### Story data

Authors
  If the author of the story is one or more staff members, select their names here. The byline can be marked up to allow more information.
Non staff author
  For authors that are not part of the organization, place the information here.
Published Status
  Required. A workflow status indicator. Only certain stories are allowed on the site.
Comment Status

  Three states are possible:

  - Allow comments shows current comments and allows users to enter new comments.
  - Disable comments does not display any comments and does not allow new comments.
  - Frozen comments shows current comments, but does not allow any new comments.

### Category Fields

If Categories is integrated, you will see a Categories section.

Primary Category
  Required. The primary category in which to file this story. This may be used in the URL of the story or RSS feeds.
Categories
  If additional the story would fit into additional categories, select them here.

### Advanced Options (hidden)

Advanced options are only required for advanced users.

Origin
  Required. Defaults to “Admin”. Used to track where this story came from, such as a wire source, external system or direct entry.
Slug
  Required. Defaults to a modified headline. The slug is a unique identifier for the story that people can read. It must be unique for each date. It is commonly used in URLS, and can only contain letters, numbers, dashes and underscores.
Publish Date, Publish Time
  The date that the story originally was published, automatically filled in to today’s date and time for a new story.
Update Date
  When the story was last modified.
Site
  Required. By default this is the current site. It is possible to run several sites with shared content.

### Story Relations

In order to make publishing to different formats easier (such as RSS/Atom feeds, ePublications, web, and print for example), we don’t recommend placing media and other related content inside the story. Story relations are pieces of content that relate to a story in some way. These could be photos, galleries, movies, documents, and other stories for example. they make it easy to mark and relate objects to use differently, depending on the output destination.

Content type
  Required. One of the configured types of content, such as photo or story.
Object id
  Required. The Id of the object. Click the magnifying glass to search and select the correct object.
Relation Type
  This is a free form field to use however you want. It allows you to tag related items for a specific use, such as a lead photo, or a pull quote.